@@ -25,12 +25,15 @@ operations on the Accessible object, such as invoking default actions or
 moving the text caret.
 """
 
-__id__        = "$Id: braille.py,v 1.56 2006/06/27 13:59:59 wwalker Exp $"
-__version__   = "$Revision: 1.56 $"
-__date__      = "$Date: 2006/06/27 13:59:59 $"
+__id__        = "$Id: braille.py,v 1.61 2006/09/28 21:09:37 wwalker Exp $"
+__version__   = "$Revision: 1.61 $"
+__date__      = "$Date: 2006/09/28 21:09:37 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import signal
+import threading
+
 import atspi
 import brl
 try:
@@ -135,6 +138,18 @@ CMD_MAX               = 0x44
 BRL_FLG_REPEAT_INITIAL= 0x800000
 BRL_FLG_REPEAT_DELAY  = 0x400000
 
+# Common names for most used BrlTTY commands, to be shown in the GUI:
+# ATM, the ones used in default.py are:
+#
+command_name = {}
+command_name[CMD_FWINLT]   = _("Line Left")
+command_name[CMD_FWINRT]   = _("Line Right")
+command_name[CMD_LNUP]     = _("Line Up")
+command_name[CMD_LNDN]     = _("Line Down")
+command_name[CMD_TOP_LEFT] = _("Top Left")
+command_name[CMD_BOT_LEFT] = _("Bottom Right")
+command_name[CMD_HOME]     = _("Cursor Position")
+
 # The size of the physical display (width, height).  The coordinate system of
 # the display is set such that the upper left is (0,0), x values increase from
 # left to right, and y values increase from top to bottom.
@@ -301,7 +316,7 @@ class Text(Region):
         self.label = label
         if self.label:
             string = self.label + " " + string
-            cursorOffset += len(self.label) + 1
+            cursorOffset += len(unicode(self.label)) + 1
 
         Region.__init__(self, string, cursorOffset)
 
@@ -317,7 +332,7 @@ class Text(Region):
         lineOffset = result[2]
         cursorOffset = caretOffset - lineOffset
         if self.label:
-            cursorOffset += len(self.label) + 1
+            cursorOffset += len(unicode(self.label)) + 1
 
         if lineOffset != self.lineOffset:
             return False
@@ -335,7 +350,7 @@ class Text(Region):
         scrolled off the display."""
 
         if self.label:
-            offset = offset - len(self.label) - 1
+            offset = offset - len(unicode(self.label)) - 1
             if offset < 0:
                 return
 
@@ -420,7 +435,7 @@ class Line:
         focusOffset = -1
         for region in self.regions:
             if region == _regionWithFocus:
-                focusOffset = len(string)
+                focusOffset = len(unicode(string))
             if region.string:
                 # [[[TODO: WDW - HACK: Replace unicode ellipses with "..."
                 # The ultimate solution is to get i18n support into
@@ -447,10 +462,10 @@ class Line:
         pos = 0
         for region in self.regions:
             string = string + region.string
-            if len(string) > offset:
+            if len(unicode(string)) > offset:
                 break
             else:
-                pos = len(string)
+                pos = len(unicode(string))
 
         return [region, offset - pos]
 
@@ -613,7 +628,7 @@ def refresh(panToCursor=True, targetCursorCell=0):
     # right of the display if we need to pan right.
     #
     if panToCursor and (cursorOffset >= 0):
-        if len(string) <= _displaySize[0]:
+        if len(unicode(string)) <= _displaySize[0]:
             _viewport[0] = 0
         elif targetCursorCell:
             _viewport[0] = max(0, cursorOffset - targetCursorCell + 1)
@@ -650,7 +665,7 @@ def refresh(panToCursor=True, targetCursorCell=0):
         monitor.destroy()
 
     beginningIsShowing = startPos == 0
-    endIsShowing = endPos >= len(string)
+    endIsShowing = endPos >= len(unicode(string))
 
 def displayRegions(regionInfo):
     """Displays a list of regions on a single line, setting focus to the
@@ -730,7 +745,7 @@ def panRight(panAmount=0):
         lineNum = _viewport[1]
         newX = _viewport[0] + panAmount
         [string, focusOffset] = _lines[lineNum].getLineInfo()
-        if newX < len(string):
+        if newX < len(unicode(string)):
             _viewport[0] = newX
 
     return oldX != _viewport[0]
@@ -789,24 +804,33 @@ def _processBrailleEvent(command):
     elif command & BRL_FLG_REPEAT_DELAY:
         return True
 
+    consumed = False
+
+    if settings.timeoutCallback and (settings.timeoutTime > 0):
+        signal.signal(signal.SIGALRM, settings.timeoutCallback)
+        signal.alarm(settings.timeoutTime)
+
     if _callback:
         try:
             # Like key event handlers, a return value of True means
             # the command was consumed.
             #
-            if _callback(command):
-                return True
+            consumed = _callback(command)
         except:
-            debug.printException(debug.LEVEL_SEVERE)
+            debug.printException(debug.LEVEL_WARNING)
+            consumed = False
 
     if (command >= 0x100) and (command < (0x100 + _displaySize[0])):
         if len(_lines) > 0:
             cursor = (command - 0x100) + _viewport[0]
             lineNum = _viewport[1]
             _lines[lineNum].processCursorKey(cursor)
-            return True
+            consumed = True
 
-    return False
+    if settings.timeoutCallback and (settings.timeoutTime > 0):
+        signal.alarm(0)
+
+    return consumed
 
 def init(callback=None, tty=7):
     """Initializes the braille module, connecting to the BrlTTY driver.
