@@ -17,6 +17,15 @@
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
 
+"""Provides a graphical braille display at the top of the screen.
+This is mainly for debugging and for demonstrations."""
+
+__id__        = "$Id: brlmon.py,v 1.13 2006/09/28 17:22:29 wwalker Exp $"
+__version__   = "$Revision: 1.13 $"
+__date__      = "$Date: 2006/09/28 17:22:29 $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
+
 import gtk
 
 class BrlMon(gtk.Window):
@@ -104,6 +113,11 @@ class BrlMon(gtk.Window):
 
         # Fill out the cells from the string.
         #
+        try:
+            string = unicode(string)
+        except:
+            string = ""
+        
         for i in range(0, len(string)):
 
             # Handle special chars so they are not interpreted by pango.
