@@ -24,9 +24,9 @@
 
 """Displays a GUI for the user to set Orca preferences."""
 
-__id__        = "$Id: orca_gui_prefs.py 1381 2006-08-28 17:00:57Z richb $"
-__version__   = "$Revision: 1381 $"
-__date__      = "$Date: 2006-08-28 13:00:57 -0400 (Mon, 28 Aug 2006) $"
+__id__        = "$Id: orca_gui_prefs.py,v 1.58 2006/10/02 19:28:56 richb Exp $"
+__version__   = "$Revision: 1.58 $"
+__date__      = "$Date: 2006/10/02 19:28:56 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -40,6 +40,7 @@ import locale
 
 import acss
 import orca
+import orca_glade
 import orca_prefs
 import orca_state
 import platform
@@ -51,37 +52,7 @@ from orca_i18n import _  # for gettext support
 
 OS = None
 
-class GladeWrapper:
-    """
-    Superclass for glade based applications. Just derive from this
-    and your subclass should create methods whose names correspond to
-    the signal handlers defined in the glade file. Any other attributes
-    in your class will be safely ignored.
-
-    This class will give you the ability to do:
-        subclass_instance.GtkWindow.method(...)
-        subclass_instance.widget_name...
-    """
-
-    def __init__(self, Filename, WindowName):
-        # Load glade file.
-        self.widgets = gtk.glade.XML(Filename, WindowName, gettext.textdomain())
-        self.GtkWindow = getattr(self, WindowName)
-
-        instance_attributes = {}
-        for attribute in dir(self.__class__):
-            instance_attributes[attribute] = getattr(self, attribute)
-        self.widgets.signal_autoconnect(instance_attributes)
-
-    def __getattr__(self, attribute):   # Called when no attribute in __dict__
-        widget = self.widgets.get_widget(attribute)
-        if widget is None:
-            raise AttributeError("Widget [" + attribute + "] not found")
-        self.__dict__[attribute] = widget   # Add reference to cache.
-
-        return widget
-
-class orcaSetupGUI(GladeWrapper):
+class orcaSetupGUI(orca_glade.GladeWrapper):
 
     def _init(self):
         """Initialize the Orca configuration GUI. Read the users current
@@ -204,8 +175,8 @@ class orcaSetupGUI(GladeWrapper):
         if serverPrefs:
             self._setServerChoice(self.serverChoices, serverPrefs[0])
 
-        voiceType = self.voiceType.get_active_text()
         self.voiceType.set_active(0)
+        voiceType = self.voiceType.get_active_text()
         self._setVoiceSettingForVoiceType(voiceType)
 
         if prefs["verbalizePunctuationStyle"] == \
@@ -387,6 +358,18 @@ class orcaSetupGUI(GladeWrapper):
         index = self._getComboBoxIndex(self.magMouseTrackingComboBox, mode)
         self.magMouseTrackingComboBox.set_active(index)
 
+        # Get the magnification source and target displays.
+        #
+        sourceDisplay = prefs["magSourceDisplay"]
+        self.magSourceDisplayEntry.set_text(sourceDisplay)
+
+        targetDisplay = prefs["magTargetDisplay"]
+        self.magTargetDisplayEntry.set_text(targetDisplay)
+
+        # General pane.
+        #
+        self.showMainWindowCheckButton.set_active(prefs["showMainWindow"])
+
     def _getComboBoxIndex(self, combobox, str):
         """ For each of the entries in the given combo box, look for str.
             Return the index of the entry if str is found.
@@ -717,6 +700,7 @@ class orcaSetupGUI(GladeWrapper):
         # then we can fail gracefully.
         #
         try:
+            self.orcaSetupWindow.realize()
             self.orcaSetupWindow.window.set_user_time(\
                 orca_state.lastInputEventTimestamp)
         except AttributeError:
@@ -1351,6 +1335,45 @@ class orcaSetupGUI(GladeWrapper):
 
         self.prefsDict["enableMagZoomerColorInversion"] = widget.get_active()
 
+    def magSourceDisplayChanged(self, widget):
+        """Signal handler for the "changed" signal for the
+           magSourceDisplayDisplayEntry GtkEntry widget.
+           The user has changed the value of the magnification source
+           display. Set the 'magSourceDisplay' preference
+           to the new value.
+
+        Arguments:
+        - widget: the component that generated the signal.
+        """
+
+        self.prefsDict["magSourceDisplay"] = widget.get_text()
+
+    def magTargetDisplayChanged(self, widget):
+        """Signal handler for the "changed" signal for the
+           magTargetDisplayEntry GtkEntry widget.
+           The user has changed the value of the magnification target
+           display. Set the 'magTargetDisplay' preference
+           to the new value.
+
+        Arguments:
+        - widget: the component that generated the signal.
+        """
+
+        self.prefsDict["magTargetDisplay"] = widget.get_text()
+
+    def showMainWindowChecked(self, widget):
+        """Signal handler for the "toggled" signal for the
+           showMainWindowCheckButton GtkCheckButton widget.
+           The user has [un]checked the 'Show Orca main window'
+           checkbox. Set the 'showMainWindow' preference
+           to the new value.
+
+        Arguments:
+        - widget: the component that generated the signal.
+        """
+
+        self.prefsDict["showMainWindow"] = widget.get_active()
+
     def helpButtonClicked(self, widget):
         """Signal handler for the "clicked" signal for the helpButton
            GtkButton widget. The user has clicked the Help button.
@@ -1361,6 +1384,38 @@ class orcaSetupGUI(GladeWrapper):
 
         print "Help not currently implemented."
 
+    def applyButtonClicked(self, widget):
+        """Signal handler for the "clicked" signal for the applyButton
+           GtkButton widget. The user has clicked the Apply button.
+           Write out the users preferences. If GNOME accessibility hadn't
+           previously been enabled, warn the user that they will need to
+           log out. Shut down any active speech servers that were started.
+           Reload the users preferences to get the new speech, braille and
+           key echo value to take effect. Do not dismiss the configuration 
+           window.
+
+        Arguments:
+        - widget: the component that generated the signal.
+        """
+
+        enable = self.speechSupportCheckbutton.get_active()
+        self.prefsDict["enableSpeech"] = enable
+        self.prefsDict["speechServerFactory"] = self.factory
+        self.prefsDict["speechServerInfo"] = self.server
+        self.prefsDict["voices"] = {
+            settings.DEFAULT_VOICE   : self.defaultVoice,
+            settings.UPPERCASE_VOICE : self.uppercaseVoice,
+            settings.HYPERLINK_VOICE : self.hyperlinkVoice
+        }
+
+        if orca_prefs.writePreferences(self.prefsDict):
+            self._say(_("Accessibility support for GNOME has just been enabled."))
+            self._say(_("You need to log out and log back in for the change to take effect."))
+
+        for factory in self.workingFactories:
+            factory.SpeechServer.shutdownActiveServers()
+        orca.loadUserSettings()
+
     def cancelButtonClicked(self, widget):
         """Signal handler for the "clicked" signal for the cancelButton
            GtkButton widget. The user has clicked the Cancel button.
@@ -1385,23 +1440,7 @@ class orcaSetupGUI(GladeWrapper):
         - widget: the component that generated the signal.
         """
 
-        enable = self.speechSupportCheckbutton.get_active()
-        self.prefsDict["enableSpeech"] = enable
-        self.prefsDict["speechServerFactory"] = self.factory
-        self.prefsDict["speechServerInfo"] = self.server
-        self.prefsDict["voices"] = {
-            settings.DEFAULT_VOICE   : self.defaultVoice,
-            settings.UPPERCASE_VOICE : self.uppercaseVoice,
-            settings.HYPERLINK_VOICE : self.hyperlinkVoice
-        }
-
-        if orca_prefs.writePreferences(self.prefsDict):
-            self._say(_("Accessibility support for GNOME has just been enabled."))
-            self._say(_("You need to log out and log back in for the change to take effect."))
-
-        for factory in self.workingFactories:
-            factory.SpeechServer.shutdownActiveServers()
-        orca.loadUserSettings()
+        self.applyButtonClicked(widget)
         self.orcaSetupWindow.hide()
 
     def windowDestroyed(self, widget):
