@@ -19,9 +19,9 @@
 
 """Custom script for gedit."""
 
-__id__        = "$Id: gedit.py 1383 2006-08-28 22:41:55Z richb $"
-__version__   = "$Revision: 1383 $"
-__date__      = "$Date: 2006-08-28 18:41:55 -0400 (Mon, 28 Aug 2006) $"
+__id__        = "$Id: gedit.py,v 1.20 2006/09/29 17:02:23 wwalker Exp $"
+__version__   = "$Revision: 1.20 $"
+__date__      = "$Date: 2006/09/29 17:02:23 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -29,6 +29,7 @@ import orca.debug as debug
 import orca.atspi as atspi
 import orca.braille as braille
 import orca.default as default
+import orca.orca as orca
 import orca.orca_state as orca_state
 import orca.rolenames as rolenames
 import orca.speech as speech
@@ -175,7 +176,7 @@ class Script(default.Script):
             #
             allTokens = []
             for i in range(0, len(allText)):
-                text = allText[i].text.getText(0, -1)
+                text = self.getText(allText[i], 0, -1)
                 tokens = text.split()
                 allTokens += tokens
 
